==> pgxRpi_1.0.3.tgz: pgxRpi/doc/Introduction_3_loadfrequency.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(pgxRpi)
library(SummarizedExperiment) # for pgxmatrix data
library(GenomicRanges) # for pgxfreq data

## -----------------------------------------------------------------------------
freq_pgxfreq <- pgxLoader(type="frequency", output ="pgxfreq",
                         filters=c("NCIT:C4038","pgx:icdom-85003"))

freq_pgxfreq

## -----------------------------------------------------------------------------
freq_pgxfreq[["NCIT:C4038"]]

## -----------------------------------------------------------------------------
mcols(freq_pgxfreq)

## -----------------------------------------------------------------------------
code <-c("C3059","C3716","C4917","C3512","C3493","C3771","C4017","C4001")
# add prefix for query
code <- sub(".",'NCIT:C',code)

## -----------------------------------------------------------------------------
freq_pgxmatrix <- pgxLoader(type="frequency",output ="pgxmatrix",filters=code)
freq_pgxmatrix

## -----------------------------------------------------------------------------
colData(freq_pgxmatrix)

## -----------------------------------------------------------------------------
head(assay(freq_pgxmatrix))

## -----------------------------------------------------------------------------
rowRanges(freq_pgxmatrix)

## -----------------------------------------------------------------------------
# access variant data
vardata <- pgxLoader(type="variant",biosample_id = c("pgxbs-kftvhmz9", "pgxbs-kftvhnqz","pgxbs-kftvhupd"),output="pgxseg")
# only keep segment cnv data
segdata <- vardata[vardata$variant_type %in% c("DUP","DEL"),]

## -----------------------------------------------------------------------------
segfreq <- segtoFreq(segdata,cohort_name="c1")
segfreq

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxfreq, filters="pgx:icdom-85003")

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxmatrix, filters = "NCIT:C3512")

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxfreq, filters='NCIT:C4038',chrom=c(1,2,3), layout = c(3,1))  

## ----fig.width=6, fig.height=6------------------------------------------------
pgxFreqplot(freq_pgxfreq, filters='pgx:icdom-85003', circos = TRUE)

## ----fig.width=6, fig.height=6------------------------------------------------
pgxFreqplot(freq_pgxfreq,filters= c("NCIT:C4038","pgx:icdom-85003"),circos = TRUE) 

## -----------------------------------------------------------------------------
# Extract the CNV frequency data frame of samples from 'icdom-85003' from 
# the previously returned object
freq_IDC <- freq_pgxfreq[['pgx:icdom-85003']]
# search the genomic bin where CCND1 is located
bin <- which(seqnames(freq_IDC) == 11 & start(freq_IDC) <= 69641156 &  
             end(freq_IDC) >= 69654474)
freq_IDC[bin,]

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxfreq,filters = 'pgx:icdom-85003', chrom = 11,highlight = bin)

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxfreq,filters = 'pgx:icdom-85003',highlight = c(1:100))

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()

==> pgxRpi_1.1.7.tgz: pgxRpi/doc/Introduction_3_loadfrequency.R <==
## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(pgxRpi)
library(SummarizedExperiment) # for pgxmatrix data
library(GenomicRanges) # for pgxfreq data

## -----------------------------------------------------------------------------
freq_pgxfreq <- pgxLoader(type="cnv_frequency", output ="pgxfreq",
                         filters=c("NCIT:C4038","pgx:icdom-85003"))

freq_pgxfreq

## -----------------------------------------------------------------------------
freq_pgxfreq[["NCIT:C4038"]]

## -----------------------------------------------------------------------------
mcols(freq_pgxfreq)

## -----------------------------------------------------------------------------
code <-c("C3059","C3716","C4917","C3512","C3493","C3771","C4017","C4001")
# add prefix for query
code <- sub(".",'NCIT:C',code)

## -----------------------------------------------------------------------------
freq_pgxmatrix <- pgxLoader(type="cnv_frequency",output ="pgxmatrix",filters=code)
freq_pgxmatrix

## -----------------------------------------------------------------------------
colData(freq_pgxmatrix)

## -----------------------------------------------------------------------------
head(assay(freq_pgxmatrix))

## -----------------------------------------------------------------------------
rowRanges(freq_pgxmatrix)

## -----------------------------------------------------------------------------
# access variant data
variants <- pgxLoader(type="g_variants",biosample_id = c("pgxbs-kftvhmz9", "pgxbs-kftvhnqz","pgxbs-kftvhupd"),output="pgxseg")
# only keep segment cnv data
segdata <- variants[variants$variant_type %in% c("DUP","DEL"),]

## -----------------------------------------------------------------------------
segfreq <- segtoFreq(segdata,cohort_name="c1")
segfreq

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxfreq, filters="pgx:icdom-85003")

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxmatrix, filters = "NCIT:C3512")

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxfreq, filters='NCIT:C4038',chrom=c(1,2,3), layout = c(3,1))  

## ----fig.width=6, fig.height=6------------------------------------------------
pgxFreqplot(freq_pgxfreq, filters='pgx:icdom-85003', circos = TRUE)

## ----fig.width=6, fig.height=6------------------------------------------------
pgxFreqplot(freq_pgxfreq,filters= c("NCIT:C4038","pgx:icdom-85003"),circos = TRUE) 

## -----------------------------------------------------------------------------
# Extract the CNV frequency data frame of samples from 'icdom-85003' from 
# the previously returned object
freq_IDC <- freq_pgxfreq[['pgx:icdom-85003']]
# search the genomic bin where CCND1 is located
bin <- which(seqnames(freq_IDC) == 11 & start(freq_IDC) <= 69641156 &  
             end(freq_IDC) >= 69654474)
freq_IDC[bin,]

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxfreq,filters = 'pgx:icdom-85003', chrom = 11,highlight = bin)

## ----fig.width=7, fig.height=5------------------------------------------------
pgxFreqplot(freq_pgxfreq,filters = 'pgx:icdom-85003',highlight = c(1:100))

## ----echo = FALSE-------------------------------------------------------------
sessionInfo()
